@@ -1,6 +1,6 @@
 package Elasticsearch::Cxn::LWP;
 {
-  $Elasticsearch::Cxn::LWP::VERSION = '0.74';
+  $Elasticsearch::Cxn::LWP::VERSION = '0.75';
 }
 
 use Moo;
@@ -21,8 +21,8 @@ sub perform_request {
 
     my $request = HTTP::Request->new(
         $method => $uri,
-        [   'Content-Type' => $params->{mime_type}
-                || $self->serializer->mime_type
+        [   'Content-Type' => $params->{mime_type},
+            %{ $self->default_headers },
         ],
         $params->{data}
     );
@@ -61,9 +61,8 @@ sub _build_handle {
 #===================================
     my $self = shift;
     my %args = (
-        default_headers => HTTP::Headers->new( $self->default_headers ),
-        keep_alive      => 1,
-        parse_head      => 0
+        keep_alive => 1,
+        parse_head => 0
     );
     if ( $self->is_https ) {
         $args{ssl_opts} = { verify_hostname => 0 };
@@ -85,7 +84,7 @@ Elasticsearch::Cxn::LWP - A Cxn implementation which uses LWP
 
 =head1 VERSION
 
-version 0.74
+version 0.75
 
 =head1 DESCRIPTION
 
